## Car brand consideration 

### Description

A car manufacturers conducted a study by randomly sampling and interviewing 1,000 consumers in a new target market to determine if consumers would consider purchasing this brand of car.

Management has already determined that the company will enter this segment. However, if brand preference is lower than 10% additional resources will be committed to advertising and sponsorship in an effort to enhance brand awareness amongst the target consumers. In the sample, 93 consumers exhibited what the company the company considered strong liking.

### Variables 

The data set has 1000 rows and two variables, `id` and `consider`. 

* id = Survey respondent id
* consider = Would the consumer consider purchasing this brand of car (yes / no)?
